@@ -100,6 +100,9 @@ class SmappeeServiceLocation(object):
 
         # Load actuators (Smappee Switches, Comfort Plugs, IO modules)
         for actuator in sl_metering_configuration.get('actuators'):
+            # temp disable IO modules until 1.6.0 release
+            if actuator.get('type') == 'INFINITY_OUTPUT_MODULE':
+                continue
             self._add_actuator(id=actuator.get('id'),
                                name=actuator.get('name'),
                                serialnumber=actuator.get('serialNumber') if 'serialNumber' in actuator else None,
@@ -163,7 +166,9 @@ class SmappeeServiceLocation(object):
             '51': 'Connect',
             '57': 'P1S1 module',
         }
-        if self.device_serial_number[:2] in model_mapping:
+        if self.device_serial_number is None:
+            return 'Smappee deactivated'
+        elif self.device_serial_number[:2] in model_mapping:
             return f'Smappee {model_mapping[self.device_serial_number[:2]]}'
         else:
             'Smappee'
@@ -273,9 +278,10 @@ class SmappeeServiceLocation(object):
                                                     actuator_id=id)
         self.actuators.get(id).state = state
 
-        # Get actuator connection state
+        # Get actuator connection state (COMFORT_PLUG is always UNREACHABLE)
         connection_state = self.smappee_api.get_actuator_connection_state(service_location_id=self.service_location_id,
                                                                           actuator_id=id)
+        connection_state = connection_state.replace('"', '')
         self.actuators.get(id).connection_state = connection_state
 
     def set_actuator_state(self, id, state, since=None, api=True):
